# -*- coding: utf-8 -*-

from bson.objectid import ObjectId

from scalymongo.document import Document
from scalymongo.connection import Connection
from scalymongo.schema_operators import OR, IS
